%undefine __cmake_in_source_build

Summary:	Reference implementation of the iCalendar data type and serialization format
Name:		libical
Version:	3.0.16
Release:	7%{?dist}
License:	LGPLv2 or MPLv2.0
URL:		https://libical.github.io/libical/
Source0:	https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	gcc gcc-c++ cmake make
BuildRequires:	pkgconfig pkgconfig(gobject-2.0) pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(libxml-2.0) pkgconfig(icu-i18n) pkgconfig(icu-uc)
BuildRequires:	python3 python3-pip python3-gobject vala
BuildRequires:	perl(Getopt::Std) perl(lib)

Requires:	tzdata

%description
Libical is an Open Source implementation of the iCalendar protocols 
and protocol data units. The iCalendar specification describes how
calendar clients can communicate with calendar servers so users
can store their calendar data and arrange meetings with other users.

Libical implements RFC2445, RFC2446 and some of RFC2447 the CalDav
scheduling extensions in RFC6638; iCalendar extensions in RFC7986;
plus the iCalendar iMIP protocol in RFC6047.

%package devel
Summary:	Development files for libical
Requires:	%{name} = %{version}-%{release}

%description devel
This package provides libraries and header files for developing
applications that use libical.

%package glib
Summary:	GObject wrapper for libical library
Requires:	%{name} = %{version}-%{release}

%description glib
This package provides a GObject wrapper for libical library with support
of GObject Introspection.

%package glib-devel
Summary:	Development files for building against %{name}-glib
Requires:	%{name}-devel = %{version}-%{release}
Requires:	%{name}-glib = %{version}-%{release}

%description glib-devel
This package provides development files needed for building things which link against %{name}-glib.

%prep
%autosetup

%build
%{cmake} \
  -DUSE_INTEROPERABLE_VTIMEZONES:BOOL=true \
  -DICAL_ALLOW_EMPTY_PROPERTIES:BOOL=true \
  -DGOBJECT_INTROSPECTION:BOOL=true \
  -DICAL_GLIB:BOOL=true \
  -DICAL_GLIB_VAPI:BOOL=true \
  -DSHARED_ONLY:BOOL=true \
  -DICAL_BUILD_DOCS:BOOL=false

%cmake_build -j1

%install
%cmake_install

rm %{buildroot}/%{_libexecdir}/libical/ical-glib-src-generator

%check
make test ARGS="-V" -C %{_vpath_builddir}


%files
%license LICENSE
%doc README.md ReleaseNotes.txt THANKS
%{_libdir}/libical.so.3
%{_libdir}/libical.so.%{version}
%{_libdir}/libical_cxx.so.3
%{_libdir}/libical_cxx.so.%{version}
%{_libdir}/libicalss.so.3
%{_libdir}/libicalss.so.%{version}
%{_libdir}/libicalss_cxx.so.3
%{_libdir}/libicalss_cxx.so.%{version}
%{_libdir}/libicalvcal.so.3
%{_libdir}/libicalvcal.so.%{version}
%{_libdir}/girepository-1.0/ICal-3.0.typelib
%{_datadir}/gir-1.0/ICal-3.0.gir

%files devel
%doc doc/UsingLibical.md
%{_libdir}/libical.so
%{_libdir}/libical_cxx.so
%{_libdir}/libicalss.so
%{_libdir}/libicalss_cxx.so
%{_libdir}/libicalvcal.so
%{_libdir}/pkgconfig/libical.pc
%{_libdir}/cmake/LibIcal/
%{_includedir}/libical/


%files glib
%{_libdir}/libical-glib.so.3
%{_libdir}/libical-glib.so.%{version}
%{_libdir}/girepository-1.0/ICalGLib-3.0.typelib
%{_datadir}/gir-1.0/ICalGLib-3.0.gir

%files glib-devel
%{_libdir}/libical-glib.so
%{_libdir}/pkgconfig/libical-glib.pc
%{_includedir}/libical-glib/
%{_datadir}/vala/vapi/libical-glib.vapi

%changelog
* Fri Dec 20 2024 Rebuild Robot <rebot@opencloudos.org> - 3.0.16-7
- [Type] other
- [DESC] Rebuilt for icu

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.0.16-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.0.16-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.0.16-4
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 3.0.16-3
- Rebuilt for icu 73.2

* Thu Jul 13 2023 Shuo Wang <abushwang@tencent.com> - 3.0.16-2
- update Source

* Wed Jul 12 2023 Shuo Wang <abushwang@tencent.com> - 3.0.16-1
- update to 3.0.16

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.0.13-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.0.13-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Nov 17 2022 cunshunxia <cunshunxia@tencent.com> - 3.0.13-1
- initial build
